Module errors

Module errors 

Enums

ConcurrentCollectionError
Errors that can occur when using the concurrent collections from the collections module.
FsError
Errors that can occur when working with the filesystem module.
ParseError
Errors that can occur when parsing numbers.