Humanizer

Struct Humanizer 

pub struct Humanizer { /* private fields */ }
A struct that can be used to humanize numbers with custom units.

Implementations

Source

impl Humanizer

pub fn new(units: &[&str]) -> Self

Creates a new humanizer with the given units.

Note: the first unit is the default one so it’s usually empty unless it’s bytes.

Arguments
  • units - The units to use when humanizing numbers.
Returns

A new humanizer with the given units.

Panics

Panics if units is empty.

pub fn with_space_before_unit(self, space_before_unit: bool) -> Self

Sets whether or not to add a space before the unit (default: true). Example: true -> “1 MB”, false -> “1MB”.

pub fn with_division_factor<F>(self, factor: F) -> Self
where F: Into<f64>,

Sets the division factor between units (default: 1000.0). Example: Use 1024.0 for binary prefixes (KiB, MiB, etc.).

Panics

Panics if the division factor is less than or equal to 0.

pub fn format<U>(&self, value: U) -> String
where U: Zero + AsPrimitive<f64> + PartialEq,

Formats a number into a human readable string using the humanizer’s units.

Example
use handy::human::Humanizer;

let humanizer = Humanizer::new(&["", "k", "m", "b", "t"]).with_space_before_unit(false);
assert_eq!(humanizer.format(123_456_789), "123m");
Arguments
  • value - The value to format.
Returns

A human readable string using the humanizer’s units.

pub fn format_as_parts<U>(&self, value: U) -> (f64, &str)
where U: Zero + AsPrimitive<f64> + PartialEq + Copy,

Formats a number into a human readable string using the humanizer’s units but returns the value and the unit.

Example
use handy::human::Humanizer;

let humanizer = Humanizer::new(&["", "k", "m", "b", "t"]);
assert_eq!(humanizer.format_as_parts(123_456_789), (123.456789, "m"));
Arguments
  • value - The value to format.
Returns
  • f64 - The value.
  • &str - The unit.