Constants
- ERROR_
MARGIN - The margin of error for string similarity scores.
Functions
- glob_
to_ regex_ pattern - Converts a glob pattern to a regex pattern.
- is_
close_ to_ upper_ bound - Checks if a string similarity score is close to the upper bound (1.0), which (according to the
ERROR_MARGIN) indicates a perfect match. - match_
filename_ with_ glob_ pattern - Checks if a path’s filename matches a glob pattern.
- match_
string - Returns a similarity score between two strings using a fuzzy matching algorithm.
- string_
similarity - Returns a similarity score between two strings using a fuzzy matching algorithm that relies on Jaro-Winkler instead Levenshtein. Use this over
match_string.